Teva Hurricane 2 Sports Sandals - Kids, 14013 | Kid's Sandals & Water Shoes | Kids Footwear | FOOTWEAR | items from Campmor.
Description: Teva Kid's Hurricane 2 is built on a high-traction Durabrasion Rubber? outsole and features classic Teva sandal strapping architecture. Quick drying webbing upper.

Backpack: 0 item(s) subtotal: $0.00
Your backpack is empty.

1-800-226-7667 |
What can we help you find? Press the access key plus 0 to focus on the search box
| 20% OFF ONE FULL PRICE ITEM. One Time Use Not valid on clearance items or items ending in .96 and SUP paddle boards. Some brand exclusions apply: Garmin GoPro Hobie Mountain Hardwear Outdoor Research Patagonia Pearl Izumi Thorlos Sierra Designs Sorel UGG Cannot be combined with other offers. Not Valid on Holiday Specials. Online Only. Not valid in retail store or on retail store pricing. Close |

Close
[ { "catentry_id" : "50022507", "partnumber" : "14013", "itempartnumber" : "14013ARM10M", "offerprice" : "24.98", "listprice" : "32.00", "savings" : "$7.02", "savingspercent" : "22.00%", "ItemMainImage" : "/wcsstore/Campmor/static/images/../images/items/main/14013arm.jpg", "ItemZoomImage" : "/wcsstore/Campmor/static/images/../images/items/larger/14013arm.jpg", "Attributes" : { "Color_Boomerang Army":"1" , "Size_10":"2" } }, ]

View all brand products |  |
Larger Image here
Close
# Teva Hurricane 2 Sports Sandals - Kids
$24.98 $24.98 List Price: $32.00 $32.00 SAVINGS: $7.02 (22.00%) $7.02 (22.00%) | Item #: 14013 14013
Available Colors: |
Boomerang Army
Available Sizes: |
10
Quantity: |
Logon to Add to Wish List
EMAIL TO FRIEND
SHIPPING INFO
CAMPMOR GUARANTEE
## Our Guarantee
## If you're not happy with your purchase from Campmor, then we're not happy either. Your satisfaction is our goal. You may return any item*, in new, sellable condition, for any reason, within one year of purchase, when accompanied by your receipt or packing slip. New condition means: - tags still on - packaging intact - unworn - unwashed - unstained - unscuffed - no tears - no odors If you've used an item and find it to be defective, we will exchange or repair the item within one year of purchase date, when returned to us along with your receipt. After one year, if your purchase is not performing to your satisfaction, or if you believe there to be a problem not caused by expected wear and tear, please contact the manufacturer directly. We recommend you save all packaging, manufacturer's warranty information, receipts and invoices, to facilitate the return process, should the need arise. * All climbing equipment and food items are final sale. For your safety, we cannot accept returns on these items. When returning merchandise to Campmor, carefully wrap the items and return them Parcel Post insured or UPS. Parcels must be returned shipping charges prepaid. C.O.D. returns can not be accepted and will be refused. Enclose the return form on the reverse side of your invoice or a letter telling us the reason for the return, along with the name, address, and zip code of the person who placed the order. Advise us if you are looking for a refund, exchange, or repair. Campmor will refund postage due to shipping errors or defects in merchandise. We will return ship via surface delivery. ### Mail Returns To: Campmor 400 Corporate Drive Mahwah, NJ 07430 Attn: Return Department ### Refunds If your purchase was made using a credit card, that card will be issued a refund which will appear on your credit card statement. Purchases made by check or money order will be issues a refund check sent under separate cover. ### Exchanges Exchanges of purchases made by credit card will be credited back to the card. The replacement item will then be rebilled.
|  | ## You Might Also Consider |
## About Teva Hurricane 2 Sports Sandals - Kids
| Function without frills for Teva kids. Light and durable, the Teva Kid's Hurricane 2 is built on a high-traction Durabrasion Rubber™ outsole and features classic Teva sandal strapping architecture. The Teva Innovative Design Elements (T.I D.E.) Lab is where design and technology combine to create footwear sure to make your outdoor adventures better. T.I.D.E. Comfort construction based on 30 years of Teva experience. T.I.D.E. Hydro open-toe construction so water doesn't pool underfoot. Quick drying webbing upper. Universal strapping system with three points of adjustment for a custom fit. Padded heel strap. Microban® zinc based anti-microbial protection. Compression-molded EVA midsole. Soft Shoc Pad™ in the heel for shock absorption. T.I.D.E. Grip - Durabrasion Rubber™ outsole gives you a solid balance of performance and durability without being overkill for everyday activities. Avg. wt. 6.2 oz. |

| REVIEWS Q & A |  |
WE ALSO RECOMMEND: